==> pegasus-support-1.6.3-sources.jar: com/thebeastshop/support/vo/operation/ConfigCouponVO.java <==
package com.thebeastshop.support.vo.operation;

import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

public class ConfigCouponVO implements Serializable {
	/**
	 * 
	 */

	private String name;// 领券页名称
	private String title;// 领券页标题
	private Integer purpose;// 领券页用途：1.分享APP 2.BD合作
	private String iosTD;// IOS打点数据
	private String androidTD;// Android打点数据
	private Integer relatedType;// 关联信息类型 1.优惠券ID 2.商品ID
	private Long relatedId;// 关联信息ID
	private String relatedLink;// 关联链接
	private Share share;// 分享实体
	private String dataPack;// 领券页配置实体
	private String error;// 异常信息
	private Boolean skip;// 是否跳转到下载页

	public Boolean getSkip() {
		return skip;
	}

	public void setSkip(Boolean skip) {
		this.skip = skip;
	}

	public String getError() {
		return error;
	}

	public void setError(String error) {
		this.error = error;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public Integer getPurpose() {
		return purpose;
	}

	public void setPurpose(Integer purpose) {
		this.purpose = purpose;
	}

	public String getIosTD() {
		return iosTD;
	}

	public void setIosTD(String iosTD) {
		this.iosTD = iosTD;
	}

	public String getAndroidTD() {
		return androidTD;
	}

	public void setAndroidTD(String androidTD) {
		this.androidTD = androidTD;
	}

	public Integer getRelatedType() {
		return relatedType;
	}

	public void setRelatedType(Integer relatedType) {
		this.relatedType = relatedType;
	}

	public Long getRelatedId() {
		return relatedId;
	}

	public void setRelatedId(Long relatedId) {
		this.relatedId = relatedId;
	}

	public String getRelatedLink() {
		return relatedLink;
	}

	public void setRelatedLink(String relatedLink) {
		this.relatedLink = relatedLink;
	}

	public Share getShare() {
		return share;
	}

	public void setShare(Share share) {
		this.share = share;
	}

	public String getDataPack() {
		return dataPack;
	}

	public void setDataPack(String dataPack) {
		this.dataPack = dataPack;
	}

	@Override
	public String toString() {
		return new ToStringBuilder(this).append("name", name).append("title", title).append("purpose", purpose).append("iosTD", iosTD).append("androidTD", androidTD).append("relatedType", relatedType).append("relatedId", relatedId).append("relatedLink", relatedLink).append("share", share).append("dataPack", dataPack).toString();
	}

}

==> pegasus-support-1.6.30-sources.jar: com/thebeastshop/support/vo/operation/ConfigCouponVO.java <==
package com.thebeastshop.support.vo.operation;

import java.io.Serializable;

import org.apache.commons.lang3.builder.ToStringBuilder;

public class ConfigCouponVO implements Serializable {
	/**
	 * 
	 */
	private String id; //领券页id（加密后字符）
	private String name;// 领券页名称
	private String title;// 领券页标题
	private Integer purpose;// 领券页用途：1.分享APP 2.BD合作
	private String iosTD;// IOS打点数据
	private String androidTD;// Android打点数据
	private Integer relatedType;// 关联信息类型 1.优惠券ID 2.商品ID
	private Long relatedId;// 关联信息ID
	private String relatedLink;// 关联链接
	private Share share;// 分享实体
	private String dataPack;// 领券页配置实体
	private String error;// 异常信息
	private Boolean skip;// 是否跳转到下载页

	public String getId() {
		return id;
	}

	public void setId(String id) {
		this.id = id;
	}

	public Boolean getSkip() {
		return skip;
	}

	public void setSkip(Boolean skip) {
		this.skip = skip;
	}

	public String getError() {
		return error;
	}

	public void setError(String error) {
		this.error = error;
	}

	public String getName() {
		return name;
	}

	public void setName(String name) {
		this.name = name;
	}

	public String getTitle() {
		return title;
	}

	public void setTitle(String title) {
		this.title = title;
	}

	public Integer getPurpose() {
		return purpose;
	}

	public void setPurpose(Integer purpose) {
		this.purpose = purpose;
	}

	public String getIosTD() {
		return iosTD;
	}

	public void setIosTD(String iosTD) {
		this.iosTD = iosTD;
	}

	public String getAndroidTD() {
		return androidTD;
	}

	public void setAndroidTD(String androidTD) {
		this.androidTD = androidTD;
	}

	public Integer getRelatedType() {
		return relatedType;
	}

	public void setRelatedType(Integer relatedType) {
		this.relatedType = relatedType;
	}

	public Long getRelatedId() {
		return relatedId;
	}

	public void setRelatedId(Long relatedId) {
		this.relatedId = relatedId;
	}

	public String getRelatedLink() {
		return relatedLink;
	}

	public void setRelatedLink(String relatedLink) {
		this.relatedLink = relatedLink;
	}

	public Share getShare() {
		return share;
	}

	public void setShare(Share share) {
		this.share = share;
	}

	public String getDataPack() {
		return dataPack;
	}

	public void setDataPack(String dataPack) {
		this.dataPack = dataPack;
	}

	@Override
	public String toString() {
		return new ToStringBuilder(this)
				.append("id", id)
				.append("name", name)
				.append("title", title)
				.append("purpose", purpose)
				.append("iosTD", iosTD)
				.append("androidTD", androidTD)
				.append("relatedType", relatedType)
				.append("relatedId", relatedId)
				.append("relatedLink", relatedLink)
				.append("share", share)
				.append("dataPack", dataPack)
				.append("error", error)
				.append("skip", skip)
				.toString();
	}
}
